/* downloader.c generated by valac 0.36.1.38-6532, the Vala compiler
 * generated from downloader.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <libsoup/soup.h>
#include <osinfo/osinfo.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_DOWNLOAD (boxes_download_get_type ())
#define BOXES_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownload))
#define BOXES_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))
#define BOXES_IS_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOAD))
#define BOXES_IS_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOAD))
#define BOXES_DOWNLOAD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))

typedef struct _BoxesDownload BoxesDownload;
typedef struct _BoxesDownloadClass BoxesDownloadClass;
typedef struct _BoxesDownloadPrivate BoxesDownloadPrivate;
enum  {
	BOXES_DOWNLOAD_DUMMY_PROPERTY,
	BOXES_DOWNLOAD_LAST_PROPERTY
};
static GParamSpec* boxes_download_properties[BOXES_DOWNLOAD_LAST_PROPERTY];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _BoxesParamSpecDownload BoxesParamSpecDownload;

#define BOXES_TYPE_DOWNLOADER (boxes_downloader_get_type ())
#define BOXES_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloader))
#define BOXES_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))
#define BOXES_IS_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOADER))
#define BOXES_IS_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOADER))
#define BOXES_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))

typedef struct _BoxesDownloader BoxesDownloader;
typedef struct _BoxesDownloaderClass BoxesDownloaderClass;
typedef struct _BoxesDownloaderPrivate BoxesDownloaderPrivate;
enum  {
	BOXES_DOWNLOADER_DUMMY_PROPERTY,
	BOXES_DOWNLOADER_LAST_PROPERTY
};
static GParamSpec* boxes_downloader_properties[BOXES_DOWNLOADER_LAST_PROPERTY];
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _boxes_download_unref0(var) ((var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesDownloaderDownloadData BoxesDownloaderDownloadData;
typedef struct _Block104Data Block104Data;
typedef struct _BoxesDownloaderDownloadFromHttpData BoxesDownloaderDownloadFromHttpData;
typedef struct _BoxesDownloaderFetchOsLogoData BoxesDownloaderFetchOsLogoData;
typedef struct _BoxesDownloaderFetchMediaData BoxesDownloaderFetchMediaData;
typedef struct _Block105Data Block105Data;
typedef struct _BoxesDownloaderAwaitDownloadData BoxesDownloaderAwaitDownloadData;
typedef struct _Block106Data Block106Data;
typedef struct _BoxesDownloaderDownloadFromFilesystemData BoxesDownloaderDownloadFromFilesystemData;
enum  {
	BOXES_DOWNLOADER_DOWNLOADED_SIGNAL,
	BOXES_DOWNLOADER_DOWNLOAD_FAILED_SIGNAL,
	BOXES_DOWNLOADER_LAST_SIGNAL
};
static guint boxes_downloader_signals[BOXES_DOWNLOADER_LAST_SIGNAL] = {0};

struct _BoxesDownload {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesDownloadPrivate * priv;
	gchar* uri;
	GFile* remote_file;
	GFile* cached_file;
	BoxesActivityProgress* progress;
};

struct _BoxesDownloadClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesDownload *self);
};

struct _BoxesParamSpecDownload {
	GParamSpec parent_instance;
};

struct _BoxesDownloader {
	GObject parent_instance;
	BoxesDownloaderPrivate * priv;
};

struct _BoxesDownloaderClass {
	GObjectClass parent_class;
};

struct _BoxesDownloaderPrivate {
	SoupSession* session;
	GHashTable* downloads;
};

struct _BoxesDownloaderDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesDownloader* self;
	GFile* remote_file;
	gchar** cached_paths;
	gint cached_paths_length1;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	GFile* result;
	gchar* uri;
	GFile* _tmp0_;
	gchar* _tmp1_;
	BoxesDownload* download;
	GHashTable* _tmp2_;
	const gchar* _tmp3_;
	gconstpointer _tmp4_;
	BoxesDownload* _tmp5_;
	gchar* cached_path;
	gchar** _tmp6_;
	gint _tmp6__length1;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	BoxesDownload* _tmp9_;
	GFile* _tmp10_;
	BoxesDownload* _tmp11_;
	const gchar* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	GFile* _tmp14_;
	GFile* _tmp15_;
	GFile* cached_file;
	GFile* _tmp16_;
	gchar** _tmp17_;
	gint _tmp17__length1;
	GFile* _tmp18_;
	GFile* _tmp19_;
	gchar* tmp_path;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GFile* tmp_file;
	const gchar* _tmp22_;
	GFile* _tmp23_;
	const gchar* _tmp24_;
	GFile* _tmp25_;
	GFile* _tmp26_;
	BoxesActivityProgress* _tmp27_;
	BoxesDownload* _tmp28_;
	GHashTable* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	BoxesDownload* _tmp32_;
	BoxesDownload* _tmp33_;
	gboolean _tmp34_;
	GFile* _tmp35_;
	gboolean _tmp36_;
	GFile* _tmp37_;
	gboolean _tmp38_;
	BoxesDownload* _tmp39_;
	GCancellable* _tmp40_;
	BoxesDownload* _tmp41_;
	GCancellable* _tmp42_;
	GError* _error_;
	BoxesDownload* _tmp43_;
	GError* _tmp44_;
	GError* _tmp45_;
	GError* _tmp46_;
	GHashTable* _tmp47_;
	const gchar* _tmp48_;
	const gchar* _tmp49_;
	GFile* _tmp50_;
	GFile* _tmp51_;
	GFile* _tmp52_;
	GCancellable* _tmp53_;
	BoxesDownload* _tmp54_;
	GFile* _tmp55_;
	GFile* _tmp56_;
	const gchar* _tmp57_;
	const gchar* _tmp58_;
	BoxesDownload* _tmp59_;
	GError * _inner_error_;
};

struct _Block104Data {
	int _ref_count_;
	BoxesDownloader* self;
	SoupMessage* msg;
	GError* err;
	gint64 total_num_bytes;
	GFileOutputStream* cached_file_stream;
	gint64 current_num_bytes;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderDownloadFromHttpData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesDownloader* self;
	BoxesDownload* download;
	GCancellable* cancellable;
	Block104Data* _data104_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	const gchar* _tmp2_;
	SoupMessage* _tmp3_;
	SoupMessage* _tmp4_;
	SoupMessageBody* _tmp5_;
	SoupAddress* address;
	SoupMessage* _tmp6_;
	SoupAddress* _tmp7_;
	SoupAddress* _tmp8_;
	GNetworkAddress* connectable;
	SoupAddress* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	SoupAddress* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
	GNetworkAddress* _tmp15_;
	GNetworkMonitor* network_monitor;
	GNetworkMonitor* _tmp16_;
	GNetworkMonitor* _tmp17_;
	gboolean _tmp18_;
	GNetworkMonitor* _tmp19_;
	GNetworkAddress* _tmp20_;
	gboolean _tmp21_;
	SoupAddress* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	SoupAddress* _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	GError* _tmp28_;
	gulong cancelled_id;
	GCancellable* _tmp29_;
	GCancellable* _tmp30_;
	gulong _tmp31_;
	SoupMessage* _tmp32_;
	BoxesDownload* _tmp33_;
	GFile* _tmp34_;
	GFileOutputStream* _tmp35_;
	SoupMessage* _tmp36_;
	SoupSession* _tmp37_;
	SoupMessage* _tmp38_;
	SoupMessage* _tmp39_;
	gulong _tmp40_;
	GCancellable* _tmp41_;
	gulong _tmp42_;
	GFileOutputStream* _tmp43_;
	GCancellable* _tmp44_;
	SoupMessage* _tmp45_;
	guint _tmp46_;
	guint _tmp47_;
	BoxesDownload* _tmp48_;
	GFile* _tmp49_;
	GError* _tmp50_;
	GQuark _tmp51_;
	SoupMessage* _tmp52_;
	guint _tmp53_;
	guint _tmp54_;
	SoupMessage* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	GError* _tmp59_;
	GError* _tmp60_;
	GError* _tmp61_;
	GError * _inner_error_;
};

struct _BoxesDownloaderFetchOsLogoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	GtkImage* image;
	OsinfoOs* os;
	gint size;
	gchar* logo_url;
	OsinfoOs* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	OsinfoOs* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GFile* remote_file;
	const gchar* _tmp7_;
	GFile* _tmp8_;
	gchar* system_cached_path;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* cached_path;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar** cached_paths;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar** _tmp21_;
	gint cached_paths_length1;
	gint _cached_paths_size_;
	const gchar* _tmp22_;
	gchar** _tmp23_;
	gint _tmp23__length1;
	const gchar* _tmp24_;
	gchar* _tmp25_;
	GFile* cached_file;
	BoxesDownloader* _tmp26_;
	BoxesDownloader* _tmp27_;
	GFile* _tmp28_;
	gchar** _tmp29_;
	gint _tmp29__length1;
	BoxesActivityProgress* _tmp30_;
	BoxesActivityProgress* _tmp31_;
	GFile* _tmp32_;
	GFile* _tmp33_;
	GdkPixbuf* pixbuf;
	GFile* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	GdkPixbuf* _tmp39_;
	GdkPixbuf* _tmp40_;
	GtkImage* _tmp41_;
	GdkPixbuf* _tmp42_;
	GError* _error_;
	const gchar* _tmp43_;
	GError* _tmp44_;
	const gchar* _tmp45_;
	GError * _inner_error_;
};

struct _BoxesDownloaderFetchMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	gchar* uri;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	gchar* result;
	GFile* file;
	const gchar* _tmp0_;
	GFile* _tmp1_;
	gchar* basename;
	GFile* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	BoxesDownloader* downloader;
	BoxesDownloader* _tmp9_;
	gchar* cache;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	const gchar* _tmp14_;
	GFile* _tmp15_;
	gchar* _tmp16_;
	gchar** _tmp17_;
	gchar** _tmp18_;
	gint _tmp18__length1;
	BoxesActivityProgress* _tmp19_;
	GCancellable* _tmp20_;
	GFile* _tmp21_;
	GFile* _tmp22_;
	BoxesActivityProgress* _tmp23_;
	GError * _inner_error_;
};

struct _Block105Data {
	int _ref_count_;
	BoxesDownloader* self;
	GFile* downloaded_file;
	GError* download_error;
	GSourceFunc callback;
	gpointer callback_target;
	GDestroyNotify callback_target_destroy_notify;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderAwaitDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesDownloader* self;
	BoxesDownload* download;
	gchar* cached_path;
	BoxesActivityProgress* progress;
	GFile* result;
	Block105Data* _data105_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesActivityProgress* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	gulong downloaded_id;
	gulong _tmp4_;
	gulong downloaded_failed_id;
	gulong _tmp5_;
	BoxesDownload* _tmp6_;
	const gchar* _tmp7_;
	BoxesDownload* _tmp8_;
	const gchar* _tmp9_;
	GError* _tmp10_;
	GFile* cached_file;
	gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	GFile* _tmp16_;
	GFile* _tmp17_;
	GFile* _tmp18_;
	GError * _inner_error_;
};

struct _Block106Data {
	int _ref_count_;
	BoxesDownloader* self;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderDownloadFromFilesystemData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gboolean _task_complete_;
	BoxesDownloader* self;
	BoxesDownload* download;
	GCancellable* cancellable;
	Block106Data* _data106_;
	BoxesDownload* _tmp0_;
	GFile* src_file;
	BoxesDownload* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	GFile* dest_file;
	BoxesDownload* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GCancellable* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GError* _error_;
	GError * _inner_error_;
};


static gpointer boxes_download_parent_class = NULL;
static gpointer boxes_downloader_parent_class = NULL;
static BoxesDownloader* boxes_downloader_downloader;
static BoxesDownloader* boxes_downloader_downloader = NULL;

gpointer boxes_download_ref (gpointer instance);
void boxes_download_unref (gpointer instance);
GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_download (GValue* value, gpointer v_object);
void boxes_value_take_download (GValue* value, gpointer v_object);
gpointer boxes_value_get_download (const GValue* value);
GType boxes_download_get_type (void) G_GNUC_CONST;
BoxesDownload* boxes_download_new (GFile* remote_file, GFile* cached_file, BoxesActivityProgress* progress);
BoxesDownload* boxes_download_construct (GType object_type, GFile* remote_file, GFile* cached_file, BoxesActivityProgress* progress);
static void boxes_download_finalize (BoxesDownload * obj);
GType boxes_downloader_get_type (void) G_GNUC_CONST;
#define BOXES_DOWNLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DOWNLOADER, BoxesDownloaderPrivate))
BoxesDownloader* boxes_downloader_get_instance (void);
static BoxesDownloader* boxes_downloader_new (void);
static BoxesDownloader* boxes_downloader_construct (GType object_type);
static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os);
static void _g_free0_ (gpointer var);
static void _boxes_download_unref0_ (gpointer var);
static void boxes_downloader_download_data_free (gpointer _data);
void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_);
static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static GFile* boxes_downloader_get_cached_file (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1);
static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_from_filesystem (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_downloader_download_from_filesystem_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_from_http_data_free (gpointer _data);
static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_);
static Block104Data* block104_data_ref (Block104Data* _data104_);
static void block104_data_unref (void * _userdata_);
static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void ___lambda64_ (Block104Data* _data104_);
static void ____lambda64__gfunc (gconstpointer data, gpointer self);
static void __lambda65_ (Block104Data* _data104_);
static void ___lambda65__soup_message_got_headers (SoupMessage* _sender, gpointer self);
static void __lambda66_ (Block104Data* _data104_, SoupMessage* msg, SoupBuffer* chunk);
static void ___lambda66__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self);
static void __lambda67_ (Block104Data* _data104_, SoupSession* session, SoupMessage* msg);
static void ___lambda67__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self);
static void boxes_downloader_fetch_os_logo_data_free (gpointer _data);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_);
static void _vala_array_add22 (gchar** * array, int* length, int* size, gchar* value);
static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_fetch_media_data_free (gpointer _data);
void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_downloader_fetch_media_co (BoxesDownloaderFetchMediaData* _data_);
static void boxes_downloader_fetch_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_await_download_data_free (gpointer _data);
static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_);
static Block105Data* block105_data_ref (Block105Data* _data105_);
static void block105_data_unref (void * _userdata_);
static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self);
static void __lambda62_ (Block105Data* _data105_, BoxesDownloader* downloader, BoxesDownload* downloaded);
static void ___lambda62__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self);
static void __lambda63_ (Block105Data* _data105_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_);
static void ___lambda63__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self);
static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_download_from_filesystem_data_free (gpointer _data);
static gboolean boxes_downloader_download_from_filesystem_co (BoxesDownloaderDownloadFromFilesystemData* _data_);
static Block106Data* block106_data_ref (Block106Data* _data106_);
static void block106_data_unref (void * _userdata_);
static void ___lambda68_ (Block106Data* _data106_, gint64 current, gint64 total);
static void ____lambda68__gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self);
static void boxes_downloader_download_from_filesystem_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void boxes_downloader_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return self ? g_object_ref (self) : NULL;
#line 571 "downloader.c"
}


BoxesDownload* boxes_download_construct (GType object_type, GFile* remote_file, GFile* cached_file, BoxesActivityProgress* progress) {
	BoxesDownload* self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	gchar* _tmp3_;
	GFile* _tmp4_;
	GFile* _tmp5_;
	BoxesActivityProgress* _tmp6_;
	BoxesActivityProgress* _tmp7_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (remote_file != NULL, NULL);
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (cached_file != NULL, NULL);
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (progress != NULL, NULL);
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = (BoxesDownload*) g_type_create_instance (object_type);
#line 10 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = remote_file;
#line 10 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 10 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->remote_file);
#line 10 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->remote_file = _tmp1_;
#line 11 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = remote_file;
#line 11 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = g_file_get_uri (_tmp2_);
#line 11 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 11 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->uri = _tmp3_;
#line 12 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = cached_file;
#line 12 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 12 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 12 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->cached_file = _tmp5_;
#line 13 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp6_ = progress;
#line 13 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 13 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 13 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->progress = _tmp7_;
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return self;
#line 627 "downloader.c"
}


BoxesDownload* boxes_download_new (GFile* remote_file, GFile* cached_file, BoxesActivityProgress* progress) {
#line 9 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return boxes_download_construct (BOXES_TYPE_DOWNLOAD, remote_file, cached_file, progress);
#line 634 "downloader.c"
}


static void boxes_value_download_init (GValue* value) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	value->data[0].v_pointer = NULL;
#line 641 "downloader.c"
}


static void boxes_value_download_free_value (GValue* value) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (value->data[0].v_pointer) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_download_unref (value->data[0].v_pointer);
#line 650 "downloader.c"
	}
}


static void boxes_value_download_copy_value (const GValue* src_value, GValue* dest_value) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (src_value->data[0].v_pointer) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = boxes_download_ref (src_value->data[0].v_pointer);
#line 660 "downloader.c"
	} else {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = NULL;
#line 664 "downloader.c"
	}
}


static gpointer boxes_value_download_peek_pointer (const GValue* value) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 672 "downloader.c"
}


static gchar* boxes_value_download_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (collect_values[0].v_pointer) {
#line 679 "downloader.c"
		BoxesDownload * object;
		object = collect_values[0].v_pointer;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (object->parent_instance.g_class == NULL) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 686 "downloader.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 690 "downloader.c"
		}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = boxes_download_ref (object);
#line 694 "downloader.c"
	} else {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 698 "downloader.c"
	}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return NULL;
#line 702 "downloader.c"
}


static gchar* boxes_value_download_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesDownload ** object_p;
	object_p = collect_values[0].v_pointer;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (!object_p) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 713 "downloader.c"
	}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (!value->data[0].v_pointer) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		*object_p = NULL;
#line 719 "downloader.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		*object_p = value->data[0].v_pointer;
#line 723 "downloader.c"
	} else {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		*object_p = boxes_download_ref (value->data[0].v_pointer);
#line 727 "downloader.c"
	}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return NULL;
#line 731 "downloader.c"
}


GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecDownload* spec;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return G_PARAM_SPEC (spec);
#line 745 "downloader.c"
}


gpointer boxes_value_get_download (const GValue* value) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 754 "downloader.c"
}


void boxes_value_set_download (GValue* value, gpointer v_object) {
	BoxesDownload * old;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_download_ref (value->data[0].v_pointer);
#line 774 "downloader.c"
	} else {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 778 "downloader.c"
	}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 784 "downloader.c"
	}
}


void boxes_value_take_download (GValue* value, gpointer v_object) {
	BoxesDownload * old;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 803 "downloader.c"
	} else {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 807 "downloader.c"
	}
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 813 "downloader.c"
	}
}


static void boxes_download_class_init (BoxesDownloadClass * klass) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_download_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	((BoxesDownloadClass *) klass)->finalize = boxes_download_finalize;
#line 823 "downloader.c"
}


static void boxes_download_instance_init (BoxesDownload * self) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->ref_count = 1;
#line 830 "downloader.c"
}


static void boxes_download_finalize (BoxesDownload * obj) {
	BoxesDownload * self;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOAD, BoxesDownload);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_handlers_destroy (self);
#line 4 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 5 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->remote_file);
#line 6 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 7 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 848 "downloader.c"
}


GType boxes_download_get_type (void) {
	static volatile gsize boxes_download_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_download_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_download_init, boxes_value_download_free_value, boxes_value_download_copy_value, boxes_value_download_peek_pointer, "p", boxes_value_download_collect_value, "p", boxes_value_download_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloadClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_download_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownload), 0, (GInstanceInitFunc) boxes_download_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_download_type_id;
		boxes_download_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesDownload", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_download_type_id__volatile, boxes_download_type_id);
	}
	return boxes_download_type_id__volatile;
}


gpointer boxes_download_ref (gpointer instance) {
	BoxesDownload * self;
	self = instance;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&self->ref_count);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return instance;
#line 873 "downloader.c"
}


void boxes_download_unref (gpointer instance) {
	BoxesDownload * self;
	self = instance;
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		BOXES_DOWNLOAD_GET_CLASS (self)->finalize (self);
#line 3 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 886 "downloader.c"
	}
}


BoxesDownloader* boxes_downloader_get_instance (void) {
	BoxesDownloader* result = NULL;
	BoxesDownloader* _tmp0_;
	BoxesDownloader* _tmp2_;
	BoxesDownloader* _tmp3_;
#line 27 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = boxes_downloader_downloader;
#line 27 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_tmp0_ == NULL) {
#line 900 "downloader.c"
		BoxesDownloader* _tmp1_;
#line 28 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp1_ = boxes_downloader_new ();
#line 28 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (boxes_downloader_downloader);
#line 28 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_downloader_downloader = _tmp1_;
#line 908 "downloader.c"
	}
#line 30 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = boxes_downloader_downloader;
#line 30 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = _tmp3_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 918 "downloader.c"
}


static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os) {
	gchar* result = NULL;
	OsinfoOs* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* logo_url = NULL;
	OsinfoProductList* derived = NULL;
	OsinfoOs* _tmp7_;
	OsinfoProductList* _tmp8_;
#line 33 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 34 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = os;
#line 34 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp0_);
#line 34 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _tmp1_;
#line 34 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_tmp2_ != NULL) {
#line 941 "downloader.c"
		OsinfoOs* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp3_ = os;
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp4_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp3_);
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp5_ = _tmp4_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		result = _tmp6_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return result;
#line 958 "downloader.c"
	}
#line 37 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	logo_url = NULL;
#line 38 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp7_ = os;
#line 38 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp8_ = osinfo_product_get_related ((OsinfoProduct*) _tmp7_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 38 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	derived = _tmp8_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	while (TRUE) {
#line 970 "downloader.c"
		gboolean _tmp9_ = FALSE;
		OsinfoProductList* _tmp10_;
		gint _tmp11_;
		OsinfoOs* parent = NULL;
		OsinfoProductList* _tmp13_;
		OsinfoEntity* _tmp14_;
		OsinfoOs* _tmp15_;
		OsinfoOs* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp10_ = derived;
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp11_ = osinfo_list_get_length ((OsinfoList*) _tmp10_);
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_tmp11_ > 0) {
#line 987 "downloader.c"
			const gchar* _tmp12_;
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp12_ = logo_url;
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp9_ = _tmp12_ == NULL;
#line 993 "downloader.c"
		} else {
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp9_ = FALSE;
#line 997 "downloader.c"
		}
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (!_tmp9_) {
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			break;
#line 1003 "downloader.c"
		}
#line 41 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp13_ = derived;
#line 41 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp14_ = osinfo_list_get_nth ((OsinfoList*) _tmp13_, 0);
#line 41 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp14_) : NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		parent = _tmp15_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp16_ = parent;
#line 43 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp17_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp16_);
#line 43 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp18_ = _tmp17_;
#line 43 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_tmp18_ != NULL) {
#line 1021 "downloader.c"
			OsinfoOs* _tmp19_;
			const gchar* _tmp20_;
			const gchar* _tmp21_;
			gchar* _tmp22_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp19_ = parent;
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp20_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp19_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp21_ = _tmp20_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp22_ = g_strdup (_tmp21_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_free0 (logo_url);
#line 44 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			logo_url = _tmp22_;
#line 1038 "downloader.c"
		} else {
			OsinfoOs* _tmp23_;
			OsinfoProductList* _tmp24_;
#line 46 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp23_ = parent;
#line 46 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp24_ = osinfo_product_get_related ((OsinfoProduct*) _tmp23_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 46 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (derived);
#line 46 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			derived = _tmp24_;
#line 1050 "downloader.c"
		}
#line 39 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (parent);
#line 1054 "downloader.c"
	}
#line 49 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = logo_url;
#line 49 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (derived);
#line 49 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 1062 "downloader.c"
}


static void _g_free0_ (gpointer var) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	var = (g_free (var), NULL);
#line 1069 "downloader.c"
}


static void _boxes_download_unref0_ (gpointer var) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	(var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL));
#line 1076 "downloader.c"
}


static BoxesDownloader* boxes_downloader_construct (GType object_type) {
	BoxesDownloader * self = NULL;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	SoupSession* _tmp3_;
	SoupSession* _tmp4_;
	const gchar* _tmp5_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = (BoxesDownloader*) g_object_new (object_type, NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = g_str_hash;
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_str_equal;
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _boxes_download_unref0_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 53 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->priv->downloads = _tmp2_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = soup_session_new ();
#line 55 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 55 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->priv->session = _tmp3_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = self->priv->session;
#line 56 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	soup_session_add_feature_by_type (_tmp4_, soup_proxy_resolver_default_get_type ());
#line 57 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = g_getenv ("SOUP_DEBUG");
#line 57 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_tmp5_ != NULL) {
#line 1114 "downloader.c"
		SoupSession* _tmp6_;
		SoupLogger* _tmp7_;
		SoupLogger* _tmp8_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp6_ = self->priv->session;
#line 58 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp7_ = soup_logger_new (SOUP_LOGGER_LOG_HEADERS, -1);
#line 58 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp8_ = _tmp7_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		soup_session_add_feature (_tmp6_, (SoupSessionFeature*) _tmp8_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_tmp8_);
#line 1128 "downloader.c"
	}
#line 52 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return self;
#line 1132 "downloader.c"
}


static BoxesDownloader* boxes_downloader_new (void) {
#line 52 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return boxes_downloader_construct (BOXES_TYPE_DOWNLOADER);
#line 1139 "downloader.c"
}


static void boxes_downloader_download_data_free (gpointer _data) {
	BoxesDownloaderDownloadData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadData, _data_);
#line 1158 "downloader.c"
}


void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
	BoxesDownloader* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	BoxesActivityProgress* _tmp4_;
	BoxesActivityProgress* _tmp5_;
	GCancellable* _tmp6_;
	GCancellable* _tmp7_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 1181 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_download_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = remote_file;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _tmp2_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_paths;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3__length1 = cached_paths_length1;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _tmp3_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = _tmp3__length1;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = progress;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp5_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp6_ = cancellable;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp7_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1223 "downloader.c"
}


GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderDownloadData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (NULL == _data_) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return NULL;
#line 1236 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 1246 "downloader.c"
}


/**
     * Downloads the given file.
     *
     * @param remote_file The remote file to download.
     * @param cached_paths Array of cache directories. The file will be saved in the directory the
     *                     first element points to.
     * @param progress The ActivityProgress object to report progress to.
     * @param cancellable The Cancellable object for cancellation.
     *
     * @return A file handle to the (now) local file.
     */
static gpointer _boxes_download_ref0 (gpointer self) {
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return self ? boxes_download_ref (self) : NULL;
#line 1264 "downloader.c"
}


static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1280 "downloader.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 102 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return self ? g_error_copy (self) : NULL;
#line 1287 "downloader.c"
}


static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_) {
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 1296 "downloader.c"
		goto _state_0;
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 1300 "downloader.c"
		goto _state_1;
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 2:
#line 1304 "downloader.c"
		goto _state_2;
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 3:
#line 1308 "downloader.c"
		goto _state_3;
		default:
#line 72 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 1313 "downloader.c"
	}
	_state_0:
#line 76 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->remote_file;
#line 76 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = g_file_get_uri (_data_->_tmp0_);
#line 76 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->uri = _data_->_tmp1_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->self->priv->downloads;
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->uri;
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_hash_table_lookup (_data_->_tmp2_, _data_->_tmp3_);
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _boxes_download_ref0 ((BoxesDownload*) _data_->_tmp4_);
#line 77 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp5_;
#line 78 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->cached_paths;
#line 78 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6__length1 = _data_->cached_paths_length1;
#line 78 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_[0];
#line 78 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_strdup (_data_->_tmp7_);
#line 78 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp8_;
#line 80 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->download;
#line 80 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp9_ != NULL) {
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = _data_->download;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = _data_->cached_path;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = _data_->progress;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_downloader_await_download (_data_->self, _data_->_tmp11_, _data_->_tmp12_, _data_->_tmp13_, boxes_downloader_download_ready, _data_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1358 "downloader.c"
		_state_1:
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = boxes_downloader_await_download_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _data_->_tmp14_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->cached_path);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_boxes_download_unref0 (_data_->download);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->uri);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1378 "downloader.c"
		}
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->_tmp10_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = NULL;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->result = _data_->_tmp15_;
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ != 0) {
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			while (_data_->_task_complete_ != TRUE) {
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1402 "downloader.c"
			}
		}
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 82 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1409 "downloader.c"
	}
#line 84 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->remote_file;
#line 84 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = _data_->cached_paths;
#line 84 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17__length1 = _data_->cached_paths_length1;
#line 84 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = boxes_downloader_get_cached_file (_data_->self, _data_->_tmp16_, _data_->_tmp17_, _data_->_tmp17__length1);
#line 84 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_file = _data_->_tmp18_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->cached_file;
#line 85 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp19_ != NULL) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->result = _data_->cached_file;
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ != 0) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			while (_data_->_task_complete_ != TRUE) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1441 "downloader.c"
			}
		}
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 86 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1448 "downloader.c"
	}
#line 88 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = _data_->cached_path;
#line 88 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_strconcat (_data_->_tmp20_, "~", NULL);
#line 88 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->tmp_path = _data_->_tmp21_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->tmp_path;
#line 89 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp23_ = g_file_new_for_path (_data_->_tmp22_);
#line 89 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->tmp_file = _data_->_tmp23_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp24_ = _data_->uri;
#line 90 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:90: Downloading '%s'...", _data_->_tmp24_);
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp25_ = _data_->remote_file;
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp26_ = _data_->tmp_file;
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = _data_->progress;
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = boxes_download_new (_data_->_tmp25_, _data_->_tmp26_, _data_->_tmp27_);
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 91 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp28_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->self->priv->downloads;
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = _data_->uri;
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = g_strdup (_data_->_tmp30_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->download;
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = _boxes_download_ref0 (_data_->_tmp32_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_hash_table_insert (_data_->_tmp29_, _data_->_tmp31_, _data_->_tmp33_);
#line 1490 "downloader.c"
	{
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = _data_->remote_file;
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = g_file_has_uri_scheme (_data_->_tmp35_, "http");
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp36_) {
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp34_ = TRUE;
#line 1500 "downloader.c"
		} else {
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp37_ = _data_->remote_file;
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp38_ = g_file_has_uri_scheme (_data_->_tmp37_, "https");
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp34_ = _data_->_tmp38_;
#line 1508 "downloader.c"
		}
#line 95 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp34_) {
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp39_ = _data_->download;
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp40_ = _data_->cancellable;
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 2;
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http (_data_->self, _data_->_tmp39_, _data_->_tmp40_, boxes_downloader_download_ready, _data_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1522 "downloader.c"
			_state_2:
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 96 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1528 "downloader.c"
				goto __catch145_g_error;
			}
		} else {
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp41_ = _data_->download;
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp42_ = _data_->cancellable;
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 3;
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_filesystem (_data_->self, _data_->_tmp41_, _data_->_tmp42_, boxes_downloader_download_ready, _data_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1542 "downloader.c"
			_state_3:
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_filesystem_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 98 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1548 "downloader.c"
				goto __catch145_g_error;
			}
		}
	}
	goto __finally145;
	__catch145_g_error:
	{
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 100 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = _data_->download;
#line 100 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = _data_->_error_;
#line 100 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_signal_emit (_data_->self, boxes_downloader_signals[BOXES_DOWNLOADER_DOWNLOAD_FAILED_SIGNAL], 0, _data_->_tmp43_, _data_->_tmp44_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = _data_->_error_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp46_ = _g_error_copy0 (_data_->_tmp45_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp46_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 1574 "downloader.c"
		goto __finally145;
	}
	__finally145:
	{
#line 104 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = _data_->self->priv->downloads;
#line 104 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = _data_->uri;
#line 104 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_hash_table_remove (_data_->_tmp47_, _data_->_tmp48_);
#line 1585 "downloader.c"
	}
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->tmp_file);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->tmp_path);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 94 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1607 "downloader.c"
	}
#line 107 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp49_ = _data_->cached_path;
#line 107 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp50_ = g_file_new_for_path (_data_->_tmp49_);
#line 107 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 107 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_file = _data_->_tmp50_;
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp51_ = _data_->tmp_file;
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp52_ = _data_->cached_file;
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp53_ = _data_->cancellable;
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_file_move (_data_->_tmp51_, _data_->_tmp52_, G_FILE_COPY_NONE, _data_->_tmp53_, NULL, NULL, &_data_->_inner_error_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->tmp_file);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->tmp_path);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 108 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1645 "downloader.c"
	}
#line 109 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp54_ = _data_->download;
#line 109 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp55_ = _data_->cached_file;
#line 109 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp56_ = _g_object_ref0 (_data_->_tmp55_);
#line 109 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->_tmp54_->cached_file);
#line 109 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp54_->cached_file = _data_->_tmp56_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp57_ = _data_->uri;
#line 111 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp58_ = _data_->cached_path;
#line 111 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:111: Downloaded '%s' and it's now locally available at" \
" '%s'.", _data_->_tmp57_, _data_->_tmp58_);
#line 112 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp59_ = _data_->download;
#line 112 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_emit (_data_->self, boxes_downloader_signals[BOXES_DOWNLOADER_DOWNLOADED_SIGNAL], 0, _data_->_tmp59_);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->tmp_file);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->tmp_path);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 1687 "downloader.c"
		}
	}
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 114 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 1694 "downloader.c"
}


static void boxes_downloader_download_from_http_data_free (gpointer _data) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadFromHttpData, _data_);
#line 1707 "downloader.c"
}


static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	BoxesDownloader* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesDownload* _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadFromHttpData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 1726 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_download_from_http_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = cancellable;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1752 "downloader.c"
}


static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (NULL == _data_) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 1764 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 1768 "downloader.c"
}


static Block104Data* block104_data_ref (Block104Data* _data104_) {
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data104_->_ref_count_);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return _data104_;
#line 1777 "downloader.c"
}


static void block104_data_unref (void * _userdata_) {
	Block104Data* _data104_;
	_data104_ = (Block104Data*) _userdata_;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data104_->_ref_count_)) {
#line 1786 "downloader.c"
		BoxesDownloader* self;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		self = _data104_->self;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data104_->cached_file_stream);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data104_->err);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data104_->msg);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data104_->download);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_slice_free (Block104Data, _data104_);
#line 1802 "downloader.c"
	}
}


static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1819 "downloader.c"
}


static void ___lambda64_ (Block104Data* _data104_) {
	BoxesDownloader* self;
	GError* _tmp0_;
	SoupSession* _tmp1_;
	SoupMessage* _tmp2_;
#line 129 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data104_->self;
#line 130 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_CANCELLED, "Cancelled by cancellable.");
#line 130 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_error_free0 (_data104_->err);
#line 130 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data104_->err = _tmp0_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = self->priv->session;
#line 131 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data104_->msg;
#line 131 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	soup_session_cancel_message (_tmp1_, _tmp2_, (guint) SOUP_STATUS_CANCELLED);
#line 1842 "downloader.c"
}


static void ____lambda64__gfunc (gconstpointer data, gpointer self) {
#line 129 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	___lambda64_ (self);
#line 1849 "downloader.c"
}


static void __lambda65_ (Block104Data* _data104_) {
	BoxesDownloader* self;
	SoupMessage* _tmp0_;
	SoupMessageHeaders* _tmp1_;
	gint64 _tmp2_;
#line 135 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data104_->self;
#line 136 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data104_->msg;
#line 136 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->response_headers;
#line 136 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = soup_message_headers_get_content_length (_tmp1_);
#line 136 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data104_->total_num_bytes = _tmp2_;
#line 1868 "downloader.c"
}


static void ___lambda65__soup_message_got_headers (SoupMessage* _sender, gpointer self) {
#line 135 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	__lambda65_ (self);
#line 1875 "downloader.c"
}


static void __lambda66_ (Block104Data* _data104_, SoupMessage* msg, SoupBuffer* chunk) {
	BoxesDownloader* self;
	SoupSession* _tmp0_;
	SoupMessage* _tmp1_;
	gboolean _tmp2_;
	gint64 _tmp3_;
	SoupBuffer* _tmp4_;
	gsize _tmp5_;
	GError * _inner_error_ = NULL;
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data104_->self;
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (chunk != NULL);
#line 146 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = self->priv->session;
#line 146 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = msg;
#line 146 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = soup_session_would_redirect (_tmp0_, _tmp1_);
#line 146 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_tmp2_) {
#line 147 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 1904 "downloader.c"
	}
#line 149 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _data104_->current_num_bytes;
#line 149 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = chunk;
#line 149 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _tmp4_->length;
#line 149 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data104_->current_num_bytes = _tmp3_ + _tmp5_;
#line 1914 "downloader.c"
	{
		GFileOutputStream* _tmp6_;
		SoupBuffer* _tmp7_;
		guint8* _tmp8_;
		gint _tmp8__length1;
		gint64 _tmp9_;
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp6_ = _data104_->cached_file_stream;
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp7_ = chunk;
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp8_ = _tmp7_->data;
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp8__length1 = (gint) _tmp7_->length;
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_output_stream_write ((GOutputStream*) _tmp6_, _tmp8_, (gsize) _tmp8__length1, NULL, &_inner_error_);
#line 154 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1933 "downloader.c"
			goto __catch146_g_error;
		}
#line 155 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp9_ = _data104_->total_num_bytes;
#line 155 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_tmp9_ > ((gint64) 0)) {
#line 1940 "downloader.c"
			BoxesDownload* _tmp10_;
			BoxesActivityProgress* _tmp11_;
			gint64 _tmp12_;
			gint64 _tmp13_;
#line 157 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp10_ = _data104_->download;
#line 157 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp11_ = _tmp10_->progress;
#line 157 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp12_ = _data104_->current_num_bytes;
#line 157 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp13_ = _data104_->total_num_bytes;
#line 157 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			boxes_activity_progress_set_progress (_tmp11_, ((gdouble) _tmp12_) / _tmp13_);
#line 1955 "downloader.c"
		}
	}
	goto __finally146;
	__catch146_g_error:
	{
		GError* e = NULL;
		GError* _tmp14_;
		GError* _tmp15_;
		SoupSession* _tmp16_;
		SoupMessage* _tmp17_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		e = _inner_error_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_inner_error_ = NULL;
#line 159 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp14_ = e;
#line 159 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp15_ = _g_error_copy0 (_tmp14_);
#line 159 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data104_->err);
#line 159 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data104_->err = _tmp15_;
#line 160 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp16_ = self->priv->session;
#line 160 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_tmp17_ = msg;
#line 160 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		soup_session_cancel_message (_tmp16_, _tmp17_, (guint) SOUP_STATUS_CANCELLED);
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (e);
#line 1986 "downloader.c"
	}
	__finally146:
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_clear_error (&_inner_error_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 1997 "downloader.c"
	}
}


static void ___lambda66__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self) {
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	__lambda66_ (self, _sender, chunk);
#line 2005 "downloader.c"
}


static void __lambda67_ (Block104Data* _data104_, SoupSession* session, SoupMessage* msg) {
	BoxesDownloader* self;
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data104_->self;
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (session != NULL);
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 165 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data104_->_async_data_);
#line 2019 "downloader.c"
}


static void ___lambda67__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self) {
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	__lambda67_ (self, session, msg);
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	block104_data_unref (self);
#line 2028 "downloader.c"
}


static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_) {
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 2037 "downloader.c"
		goto _state_0;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 2041 "downloader.c"
		goto _state_1;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 2:
#line 2045 "downloader.c"
		goto _state_2;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 3:
#line 2049 "downloader.c"
		goto _state_3;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 4:
#line 2053 "downloader.c"
		goto _state_4;
		default:
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2058 "downloader.c"
	}
	_state_0:
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_ = g_slice_new0 (Block104Data);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->_ref_count_ = 1;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->self = g_object_ref (_data_->self);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data104_->download);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->download = _data_->_tmp0_;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->_async_data_ = _data_;
#line 118 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data104_->download;
#line 118 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->uri;
#line 118 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = soup_message_new ("GET", _data_->_tmp2_);
#line 118 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->msg = _data_->_tmp3_;
#line 119 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = _data_->_data104_->msg;
#line 119 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_->response_body;
#line 119 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	soup_message_body_set_accumulate (_data_->_tmp5_, FALSE);
#line 120 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->_data104_->msg;
#line 120 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = soup_message_get_address (_data_->_tmp6_);
#line 120 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 120 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->address = _data_->_tmp8_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->address;
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = soup_address_get_name (_data_->_tmp9_);
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->address;
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = soup_address_get_port (_data_->_tmp12_);
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = (GNetworkAddress*) g_network_address_new (_data_->_tmp11_, (guint16) _data_->_tmp14_);
#line 121 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->connectable = _data_->_tmp15_;
#line 122 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = g_network_monitor_get_default ();
#line 122 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = _g_object_ref0 (_data_->_tmp16_);
#line 122 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->network_monitor = _data_->_tmp17_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->network_monitor;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = _data_->connectable;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_network_monitor_can_reach_async (_data_->_tmp19_, (GSocketConnectable*) _data_->_tmp20_, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2129 "downloader.c"
	_state_1:
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_network_monitor_can_reach_finish (_data_->_tmp19_, _data_->_res_, &_data_->_inner_error_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp21_;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block104_data_unref (_data_->_data104_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data104_ = NULL;
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2153 "downloader.c"
	}
#line 123 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (!_data_->_tmp18_) {
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp22_ = _data_->address;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = soup_address_get_name (_data_->_tmp22_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = _data_->_tmp23_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = _data_->address;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = soup_address_get_port (_data_->_tmp25_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to reach host '%s' on port '%d'", _data_->_tmp24_, _data_->_tmp27_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp28_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block104_data_unref (_data_->_data104_);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data104_ = NULL;
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 124 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2189 "downloader.c"
	}
#line 126 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->err = NULL;
#line 127 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cancelled_id = (gulong) 0;
#line 128 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->cancellable;
#line 128 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp29_ != NULL) {
#line 129 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = _data_->cancellable;
#line 129 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = g_cancellable_connect (_data_->_tmp30_, (GCallback) ____lambda64__gfunc, block104_data_ref (_data_->_data104_), block104_data_unref);
#line 129 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->cancelled_id = _data_->_tmp31_;
#line 2205 "downloader.c"
	}
#line 134 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->total_num_bytes = (gint64) 0;
#line 135 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->_data104_->msg;
#line 135 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp32_, "got-headers", (GCallback) ___lambda65__soup_message_got_headers, block104_data_ref (_data_->_data104_), (GClosureNotify) block104_data_unref, 0);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = _data_->_data104_->download;
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = _data_->_tmp33_->cached_file;
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 2;
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_file_replace_async (_data_->_tmp34_, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION, G_PRIORITY_DEFAULT, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2223 "downloader.c"
	_state_2:
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = g_file_replace_finish (_data_->_tmp34_, _data_->_res_, &_data_->_inner_error_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->cached_file_stream = _data_->_tmp35_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block104_data_unref (_data_->_data104_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data104_ = NULL;
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 139 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2247 "downloader.c"
	}
#line 143 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_->current_num_bytes = (gint64) 0;
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp36_ = _data_->_data104_->msg;
#line 145 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp36_, "got-chunk", (GCallback) ___lambda66__soup_message_got_chunk, block104_data_ref (_data_->_data104_), (GClosureNotify) block104_data_unref, 0);
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp37_ = _data_->self->priv->session;
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp38_ = _data_->_data104_->msg;
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp39_ = _g_object_ref0 (_data_->_tmp38_);
#line 164 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	soup_session_queue_message (_data_->_tmp37_, _data_->_tmp39_, ___lambda67__soup_session_callback, block104_data_ref (_data_->_data104_));
#line 168 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 3;
#line 168 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2267 "downloader.c"
	_state_3:
	;
#line 170 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp40_ = _data_->cancelled_id;
#line 170 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp40_ != ((gulong) 0)) {
#line 171 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = _data_->cancellable;
#line 171 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = _data_->cancelled_id;
#line 171 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_cancellable_disconnect (_data_->_tmp41_, _data_->_tmp42_);
#line 2280 "downloader.c"
	}
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp43_ = _data_->_data104_->cached_file_stream;
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp44_ = _data_->cancellable;
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 4;
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_output_stream_close_async ((GOutputStream*) _data_->_tmp43_, G_PRIORITY_DEFAULT, _data_->_tmp44_, boxes_downloader_download_from_http_ready, _data_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2292 "downloader.c"
	_state_4:
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_output_stream_close_finish ((GOutputStream*) _data_->_tmp43_, _data_->_res_, &_data_->_inner_error_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block104_data_unref (_data_->_data104_);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data104_ = NULL;
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 173 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2314 "downloader.c"
	}
#line 175 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp45_ = _data_->_data104_->msg;
#line 175 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_get (_data_->_tmp45_, "status-code", &_data_->_tmp46_, NULL);
#line 175 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp47_ = _data_->_tmp46_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp47_ != ((guint) SOUP_STATUS_OK)) {
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = _data_->_data104_->download;
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp49_ = _data_->_tmp48_->cached_file;
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_file_delete (_data_->_tmp49_, NULL, &_data_->_inner_error_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->network_monitor);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->connectable);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->address);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			block104_data_unref (_data_->_data104_);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_data104_ = NULL;
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 176 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 2348 "downloader.c"
		}
#line 177 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp50_ = _data_->_data104_->err;
#line 177 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp50_ == NULL) {
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp51_ = soup_http_error_quark ();
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp52_ = _data_->_data104_->msg;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_object_get (_data_->_tmp52_, "status-code", &_data_->_tmp53_, NULL);
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp54_ = _data_->_tmp53_;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp55_ = _data_->_data104_->msg;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_object_get (_data_->_tmp55_, "reason-phrase", &_data_->_tmp56_, NULL);
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp57_ = _data_->_tmp56_;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp58_ = _data_->_tmp57_;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_tmp59_ = g_error_new (_data_->_tmp51_, (gint) _data_->_tmp54_, "%s", _data_->_tmp58_);
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_error_free0 (_data_->_data104_->err);
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_data104_->err = _data_->_tmp59_;
#line 178 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->_tmp58_);
#line 2378 "downloader.c"
		}
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp60_ = _data_->_data104_->err;
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp61_ = _g_error_copy0 (_data_->_tmp60_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp61_;
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block104_data_unref (_data_->_data104_);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data104_ = NULL;
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 180 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2402 "downloader.c"
	}
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->network_monitor);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->connectable);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->address);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	block104_data_unref (_data_->_data104_);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data104_ = NULL;
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2422 "downloader.c"
		}
	}
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 117 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2429 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_data_free (gpointer _data) {
	BoxesDownloaderFetchOsLogoData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderFetchOsLogoData, _data_);
#line 2442 "downloader.c"
}


void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
	GtkImage* _tmp0_;
	GtkImage* _tmp1_;
	OsinfoOs* _tmp2_;
	OsinfoOs* _tmp3_;
	gint _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderFetchOsLogoData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (NULL, NULL, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 2461 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_fetch_os_logo_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = image;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->image = _tmp1_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = os;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->os = _tmp3_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = size;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->size = _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2487 "downloader.c"
}


void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 2497 "downloader.c"
}


static void _vala_array_add22 (gchar** * array, int* length, int* size, gchar* value) {
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if ((*length) == (*size)) {
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 2508 "downloader.c"
	}
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	(*array)[(*length)++] = value;
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	(*array)[*length] = NULL;
#line 2514 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2530 "downloader.c"
}


static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_) {
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 2539 "downloader.c"
		goto _state_0;
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 2543 "downloader.c"
		goto _state_1;
		default:
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2548 "downloader.c"
	}
	_state_0:
#line 185 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->os;
#line 185 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = boxes_downloader_fetch_os_logo_url (_data_->_tmp0_);
#line 185 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->logo_url = _data_->_tmp1_;
#line 186 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->logo_url;
#line 186 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp2_ == NULL) {
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ != 0) {
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			while (_data_->_task_complete_ != TRUE) {
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2571 "downloader.c"
			}
		}
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 187 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2578 "downloader.c"
	}
#line 189 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->os;
#line 189 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp3_);
#line 189 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 189 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->logo_url;
#line 189 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:189: %s has logo '%s'.", _data_->_tmp5_, _data_->_tmp6_);
#line 191 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->logo_url;
#line 191 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_file_new_for_uri (_data_->_tmp7_);
#line 191 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _data_->_tmp8_;
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->remote_file;
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = g_file_get_basename (_data_->_tmp9_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = boxes_get_system_logo_cache (_data_->_tmp11_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp11_);
#line 192 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->system_cached_path = _data_->_tmp13_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->remote_file;
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = g_file_get_basename (_data_->_tmp14_);
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = boxes_get_logo_cache (_data_->_tmp16_);
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp16_);
#line 193 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp18_;
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->cached_path;
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_new0 (gchar*, 1 + 1);
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_[0] = _data_->_tmp20_;
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _data_->_tmp21_;
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = 1;
#line 195 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_cached_paths_size_ = _data_->cached_paths_length1;
#line 196 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->system_cached_path;
#line 196 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp22_ != NULL) {
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = _data_->cached_paths;
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp23__length1 = _data_->cached_paths_length1;
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = _data_->system_cached_path;
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = g_strdup (_data_->_tmp24_);
#line 197 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_vala_array_add22 (&_data_->cached_paths, &_data_->cached_paths_length1, &_data_->_cached_paths_size_, _data_->_tmp25_);
#line 2652 "downloader.c"
	}
	{
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = boxes_downloader_get_instance ();
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = _data_->remote_file;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp29_ = _data_->cached_paths;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp29__length1 = _data_->cached_paths_length1;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = boxes_activity_progress_new ();
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = _data_->_tmp30_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		boxes_downloader_download (_data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_, _data_->_tmp29__length1, _data_->_tmp31_, NULL, boxes_downloader_fetch_os_logo_ready, _data_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2675 "downloader.c"
		_state_1:
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp32_ = boxes_downloader_download_finish (_data_->_tmp27_, _data_->_res_, &_data_->_inner_error_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp31_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp27_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp33_;
#line 200 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2689 "downloader.c"
			goto __catch147_g_error;
		}
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp34_ = _data_->cached_file;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = g_file_get_path (_data_->_tmp34_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->size;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = _data_->size;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = gdk_pixbuf_new_from_file_at_size (_data_->_tmp36_, _data_->_tmp37_, _data_->_tmp38_, &_data_->_inner_error_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp36_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->pixbuf = _data_->_tmp40_;
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 201 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 2714 "downloader.c"
			goto __catch147_g_error;
		}
#line 202 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = _data_->image;
#line 202 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = _data_->pixbuf;
#line 202 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		gtk_image_set_from_pixbuf (_data_->_tmp41_, _data_->_tmp42_);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->pixbuf);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 2727 "downloader.c"
	}
	goto __finally147;
	__catch147_g_error:
	{
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 204 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = _data_->logo_url;
#line 204 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = _data_->_error_;
#line 204 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = _data_->_tmp44_->message;
#line 204 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_warning ("downloader.vala:204: Error loading logo file '%s': %s", _data_->_tmp43_, _data_->_tmp45_);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 2746 "downloader.c"
	}
	__finally147:
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->system_cached_path);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->remote_file);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_clear_error (&_data_->_inner_error_);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 199 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2769 "downloader.c"
	}
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->system_cached_path);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->logo_url);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2789 "downloader.c"
		}
	}
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 184 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2796 "downloader.c"
}


static void boxes_downloader_fetch_media_data_free (gpointer _data) {
	BoxesDownloaderFetchMediaData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->result);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderFetchMediaData, _data_);
#line 2813 "downloader.c"
}


void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderFetchMediaData* _data_;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	BoxesActivityProgress* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	GCancellable* _tmp4_;
	GCancellable* _tmp5_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderFetchMediaData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (NULL, cancellable, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 2833 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_fetch_media_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = uri;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->uri = _tmp1_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = progress;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp3_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = cancellable;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp5_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_media_co (_data_);
#line 2863 "downloader.c"
}


gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error) {
	gchar* result;
	BoxesDownloaderFetchMediaData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (NULL == _data_) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return NULL;
#line 2876 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 2886 "downloader.c"
}


static void boxes_downloader_fetch_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderFetchMediaData* _data_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_media_co (_data_);
#line 2902 "downloader.c"
}


static gboolean boxes_downloader_fetch_media_co (BoxesDownloaderFetchMediaData* _data_) {
#line 208 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 208 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 2911 "downloader.c"
		goto _state_0;
#line 208 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 2915 "downloader.c"
		goto _state_1;
		default:
#line 208 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2920 "downloader.c"
	}
	_state_0:
#line 211 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->uri;
#line 211 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = g_file_new_for_uri (_data_->_tmp0_);
#line 211 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->file = _data_->_tmp1_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->file;
#line 212 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = g_file_get_basename (_data_->_tmp2_);
#line 212 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->basename = _data_->_tmp3_;
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->basename;
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp6_ != NULL) {
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp7_ = _data_->basename;
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp5_ = g_strcmp0 (_data_->_tmp7_, "") != 0;
#line 2943 "downloader.c"
	} else {
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp5_ = FALSE;
#line 2947 "downloader.c"
	}
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp5_) {
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp8_ = _data_->basename;
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp4_ = g_strcmp0 (_data_->_tmp8_, "/") != 0;
#line 2955 "downloader.c"
	} else {
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp4_ = FALSE;
#line 2959 "downloader.c"
	}
#line 213 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (_data_->_tmp4_, NULL);
#line 215 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = boxes_downloader_get_instance ();
#line 215 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->downloader = _data_->_tmp9_;
#line 216 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
#line 216 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->basename;
#line 216 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = g_build_filename (_data_->_tmp10_, _data_->_tmp11_, NULL);
#line 216 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cache = _data_->_tmp12_;
#line 219 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->progress;
#line 219 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_data_->_tmp13_, (gdouble) 0);
#line 220 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->uri;
#line 220 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:220: Downloading media from '%s' to '%s'.", _data_->_tmp14_, _data_->cache);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = _data_->file;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = g_strdup (_data_->cache);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = g_new0 (gchar*, 1 + 1);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_[0] = _data_->_tmp16_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18__length1 = 1;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->progress;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = _data_->cancellable;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download (_data_->downloader, _data_->_tmp15_, _data_->_tmp18_, 1, _data_->_tmp19_, _data_->_tmp20_, boxes_downloader_fetch_media_ready, _data_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3005 "downloader.c"
	_state_1:
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = boxes_downloader_download_finish (_data_->downloader, _data_->_res_, &_data_->_inner_error_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->_tmp22_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = (_vala_array_free (_data_->_tmp18_, _data_->_tmp18__length1, (GDestroyNotify) g_free), NULL);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cache);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->downloader);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->basename);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->file);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 221 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3031 "downloader.c"
	}
#line 222 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp23_ = _data_->progress;
#line 222 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_data_->_tmp23_, (gdouble) 1);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cache;
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->downloader);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->basename);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->file);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3053 "downloader.c"
		}
	}
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 224 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3060 "downloader.c"
}


static void boxes_downloader_await_download_data_free (gpointer _data) {
	BoxesDownloaderAwaitDownloadData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderAwaitDownloadData, _data_);
#line 3077 "downloader.c"
}


static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
	BoxesDownloader* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesDownload* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	BoxesActivityProgress* _tmp5_;
	BoxesActivityProgress* _tmp6_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderAwaitDownloadData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 3098 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_await_download_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_path;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = progress;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp6_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 3132 "downloader.c"
}


static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderAwaitDownloadData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (NULL == _data_) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return NULL;
#line 3145 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 3155 "downloader.c"
}


static Block105Data* block105_data_ref (Block105Data* _data105_) {
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data105_->_ref_count_);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return _data105_;
#line 3164 "downloader.c"
}


static void block105_data_unref (void * _userdata_) {
	Block105Data* _data105_;
	_data105_ = (Block105Data*) _userdata_;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data105_->_ref_count_)) {
#line 3173 "downloader.c"
		BoxesDownloader* self;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		self = _data105_->self;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		(_data105_->callback_target_destroy_notify == NULL) ? NULL : (_data105_->callback_target_destroy_notify (_data105_->callback_target), NULL);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data105_->callback = NULL;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data105_->callback_target = NULL;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data105_->callback_target_destroy_notify = NULL;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data105_->download_error);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data105_->downloaded_file);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data105_->download);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_slice_free (Block105Data, _data105_);
#line 3195 "downloader.c"
	}
}


static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self) {
	gboolean result;
	result = boxes_downloader_await_download_co (self);
#line 234 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 3205 "downloader.c"
}


static void __lambda62_ (Block105Data* _data105_, BoxesDownloader* downloader, BoxesDownload* downloaded) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_;
	const gchar* _tmp1_;
	BoxesDownload* _tmp2_;
	const gchar* _tmp3_;
	BoxesDownload* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data105_->self;
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloaded != NULL);
#line 236 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = downloaded;
#line 236 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 236 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data105_->download;
#line 236 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 236 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 237 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 3236 "downloader.c"
	}
#line 239 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = downloaded;
#line 239 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _tmp4_->cached_file;
#line 239 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 239 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data105_->downloaded_file);
#line 239 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data105_->downloaded_file = _tmp6_;
#line 240 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data105_->callback (_data105_->callback_target);
#line 3250 "downloader.c"
}


static void ___lambda62__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self) {
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	__lambda62_ (self, _sender, download);
#line 3257 "downloader.c"
}


static void __lambda63_ (Block105Data* _data105_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_;
	const gchar* _tmp1_;
	BoxesDownload* _tmp2_;
	const gchar* _tmp3_;
	GError* _tmp4_;
	GError* _tmp5_;
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data105_->self;
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (failed_download != NULL);
#line 243 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = failed_download;
#line 243 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 243 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data105_->download;
#line 243 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 243 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 244 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 3287 "downloader.c"
	}
#line 246 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = _error_;
#line 246 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_error_copy0 (_tmp4_);
#line 246 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_error_free0 (_data105_->download_error);
#line 246 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data105_->download_error = _tmp5_;
#line 247 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data105_->callback (_data105_->callback_target);
#line 3299 "downloader.c"
}


static void ___lambda63__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self) {
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	__lambda63_ (self, _sender, download, _error_);
#line 3306 "downloader.c"
}


static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 3322 "downloader.c"
}


static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_) {
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 3331 "downloader.c"
		goto _state_0;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 3335 "downloader.c"
		goto _state_1;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 2:
#line 3339 "downloader.c"
		goto _state_2;
		default:
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 3344 "downloader.c"
	}
	_state_0:
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_ = g_slice_new0 (Block105Data);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->_ref_count_ = 1;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->self = g_object_ref (_data_->self);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data105_->download);
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->download = _data_->_tmp0_;
#line 227 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->_async_data_ = _data_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->downloaded_file = NULL;
#line 231 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->download_error = NULL;
#line 233 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data105_->download;
#line 233 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->progress;
#line 233 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->progress;
#line 233 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_tmp2_, "progress", (GObject*) _data_->_tmp3_, "progress", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 234 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->callback = _boxes_downloader_await_download_co_gsource_func;
#line 234 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->callback_target = _data_;
#line 234 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_->callback_target_destroy_notify = NULL;
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_signal_connect_data (_data_->self, "downloaded", (GCallback) ___lambda62__boxes_downloader_downloaded, block105_data_ref (_data_->_data105_), (GClosureNotify) block105_data_unref, 0);
#line 235 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->downloaded_id = _data_->_tmp4_;
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = g_signal_connect_data (_data_->self, "download-failed", (GCallback) ___lambda63__boxes_downloader_download_failed, block105_data_ref (_data_->_data105_), (GClosureNotify) block105_data_unref, 0);
#line 242 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->downloaded_failed_id = _data_->_tmp5_;
#line 250 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->_data105_->download;
#line 250 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_->uri;
#line 250 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:250: '%s' already being downloaded. Waiting for downlo" \
"ad to complete..", _data_->_tmp7_);
#line 251 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 251 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3397 "downloader.c"
	_state_1:
	;
#line 252 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = _data_->_data105_->download;
#line 252 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->_tmp8_->uri;
#line 252 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:252: Finished waiting for '%s' to download.", _data_->_tmp9_);
#line 253 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_id);
#line 254 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_failed_id);
#line 256 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_data105_->download_error != NULL) {
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _g_error_copy0 (_data_->_data105_->download_error);
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp10_;
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block105_data_unref (_data_->_data105_);
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data105_ = NULL;
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 257 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3426 "downloader.c"
	}
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = g_file_get_path (_data_->_data105_->downloaded_file);
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->cached_path;
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = g_strcmp0 (_data_->_tmp12_, _data_->_tmp13_) != 0;
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp12_);
#line 260 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp14_) {
#line 261 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->cached_path;
#line 261 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp16_ = g_file_new_for_path (_data_->_tmp15_);
#line 261 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 261 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp16_;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp17_ = _data_->cached_file;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 2;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_file_copy_async (_data_->_data105_->downloaded_file, _data_->_tmp17_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_downloader_await_download_ready, _data_);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3456 "downloader.c"
		_state_2:
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_file_copy_finish (_data_->_data105_->downloaded_file, _data_->_res_, &_data_->_inner_error_);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			block105_data_unref (_data_->_data105_);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_data_->_data105_ = NULL;
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 262 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 3474 "downloader.c"
		}
	} else {
#line 264 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp18_ = _g_object_ref0 (_data_->_data105_->downloaded_file);
#line 264 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 264 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp18_;
#line 3483 "downloader.c"
	}
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	block105_data_unref (_data_->_data105_);
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data105_ = NULL;
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3499 "downloader.c"
		}
	}
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 266 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3506 "downloader.c"
}


static void boxes_downloader_download_from_filesystem_data_free (gpointer _data) {
	BoxesDownloaderDownloadFromFilesystemData* _data_;
	_data_ = _data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadFromFilesystemData, _data_);
#line 3519 "downloader.c"
}


static void boxes_downloader_download_from_filesystem (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromFilesystemData* _data_;
	BoxesDownloader* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesDownload* _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadFromFilesystemData);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, _callback_, _user_data_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_callback_ == NULL) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_task_complete_ = TRUE;
#line 3538 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_set_task_data (_data_->_async_result, _data_, boxes_downloader_download_from_filesystem_data_free);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = cancellable;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp4_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_filesystem_co (_data_);
#line 3564 "downloader.c"
}


static void boxes_downloader_download_from_filesystem_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	BoxesDownloaderDownloadFromFilesystemData* _data_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (NULL == _data_) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return;
#line 3576 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 3580 "downloader.c"
}


static Block106Data* block106_data_ref (Block106Data* _data106_) {
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data106_->_ref_count_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return _data106_;
#line 3589 "downloader.c"
}


static void block106_data_unref (void * _userdata_) {
	Block106Data* _data106_;
	_data106_ = (Block106Data*) _userdata_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data106_->_ref_count_)) {
#line 3598 "downloader.c"
		BoxesDownloader* self;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		self = _data106_->self;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data106_->download);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_slice_free (Block106Data, _data106_);
#line 3608 "downloader.c"
	}
}


static void ___lambda68_ (Block106Data* _data106_, gint64 current, gint64 total) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_;
	BoxesActivityProgress* _tmp1_;
	gint64 _tmp2_;
	gint64 _tmp3_;
#line 280 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = _data106_->self;
#line 281 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data106_->download;
#line 281 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->progress;
#line 281 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp2_ = current;
#line 281 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp3_ = total;
#line 281 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_tmp1_, ((gdouble) _tmp2_) / _tmp3_);
#line 3631 "downloader.c"
}


static void ____lambda68__gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self) {
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	___lambda68_ (self, current_num_bytes, total_num_bytes);
#line 3638 "downloader.c"
}


static void boxes_downloader_download_from_filesystem_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromFilesystemData* _data_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_task_complete_ = TRUE;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_filesystem_co (_data_);
#line 3654 "downloader.c"
}


static gboolean boxes_downloader_download_from_filesystem_co (BoxesDownloaderDownloadFromFilesystemData* _data_) {
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 0:
#line 3663 "downloader.c"
		goto _state_0;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		case 1:
#line 3667 "downloader.c"
		goto _state_1;
		default:
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 3672 "downloader.c"
	}
	_state_0:
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_ = g_slice_new0 (Block106Data);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_->_ref_count_ = 1;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_->self = g_object_ref (_data_->self);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data106_->download);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_->download = _data_->_tmp0_;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_->_async_data_ = _data_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data106_->download;
#line 271 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->remote_file;
#line 271 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _g_object_ref0 (_data_->_tmp2_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->src_file = _data_->_tmp3_;
#line 272 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = _data_->_data106_->download;
#line 272 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_->cached_file;
#line 272 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 272 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->dest_file = _data_->_tmp6_;
#line 3705 "downloader.c"
	{
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp7_ = g_file_get_path (_data_->src_file);
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp9_ = g_file_get_path (_data_->dest_file);
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_debug ("downloader.vala:275: Copying '%s' to '%s'..", _data_->_tmp8_, _data_->_tmp10_);
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp10_);
#line 275 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp8_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = _data_->cancellable;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_file_copy_async (_data_->src_file, _data_->dest_file, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, _data_->_tmp11_, ____lambda68__gfile_progress_callback, _data_->_data106_, boxes_downloader_download_from_filesystem_ready, _data_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3729 "downloader.c"
		_state_1:
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_file_copy_finish (_data_->src_file, _data_->_res_, &_data_->_inner_error_);
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 276 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
#line 3737 "downloader.c"
				goto __catch148_g_io_error_exists;
			}
			goto __finally148;
		}
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = g_file_get_path (_data_->src_file);
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = g_file_get_path (_data_->dest_file);
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_debug ("downloader.vala:283: Copied '%s' to '%s'.", _data_->_tmp13_, _data_->_tmp15_);
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp15_);
#line 283 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp13_);
#line 3756 "downloader.c"
	}
	goto __finally148;
	__catch148_g_io_error_exists:
	{
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 3767 "downloader.c"
	}
	__finally148:
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_task_return_error (_data_->_async_result, _data_->_inner_error_);
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->dest_file);
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->src_file);
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		block106_data_unref (_data_->_data106_);
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		_data_->_data106_ = NULL;
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 274 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3786 "downloader.c"
	}
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->dest_file);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->src_file);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	block106_data_unref (_data_->_data106_);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_data_->_data106_ = NULL;
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ != 0) {
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		while (_data_->_task_complete_ != TRUE) {
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3804 "downloader.c"
		}
	}
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 269 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3811 "downloader.c"
}


static GFile* boxes_downloader_get_cached_file (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1) {
	GFile* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
#line 287 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 287 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (remote_file != NULL, NULL);
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0_ = cached_paths;
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_tmp0__length1 = cached_paths_length1;
#line 3827 "downloader.c"
	{
		gchar** path_collection = NULL;
		gint path_collection_length1 = 0;
		gint _path_collection_size_ = 0;
		gint path_it = 0;
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		path_collection = _tmp0_;
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		path_collection_length1 = _tmp0__length1;
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		for (path_it = 0; path_it < _tmp0__length1; path_it = path_it + 1) {
#line 3839 "downloader.c"
			gchar* _tmp1_;
			gchar* path = NULL;
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			_tmp1_ = g_strdup (path_collection[path_it]);
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
			path = _tmp1_;
#line 3846 "downloader.c"
			{
				GFile* cached_file = NULL;
				const gchar* _tmp2_;
				GFile* _tmp3_;
				GFile* _tmp4_;
				gboolean _tmp5_;
#line 289 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_tmp2_ = path;
#line 289 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_tmp3_ = g_file_new_for_path (_tmp2_);
#line 289 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				cached_file = _tmp3_;
#line 290 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_tmp4_ = cached_file;
#line 290 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_tmp5_ = g_file_query_exists (_tmp4_, NULL);
#line 290 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				if (_tmp5_) {
#line 3865 "downloader.c"
					GFile* _tmp6_;
					gchar* _tmp7_;
					gchar* _tmp8_;
					const gchar* _tmp9_;
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_tmp6_ = remote_file;
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_tmp7_ = g_file_get_uri (_tmp6_);
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_tmp8_ = _tmp7_;
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_tmp9_ = path;
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					g_debug ("downloader.vala:291: '%s' already available locally at '%s'. Not downl" \
"oading.", _tmp8_, _tmp9_);
#line 291 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_g_free0 (_tmp8_);
#line 292 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					result = cached_file;
#line 292 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					_g_free0 (path);
#line 292 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
					return result;
#line 3888 "downloader.c"
				}
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_g_object_unref0 (cached_file);
#line 288 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
				_g_free0 (path);
#line 3894 "downloader.c"
			}
		}
	}
#line 296 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	result = NULL;
#line 296 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	return result;
#line 3902 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 2);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3921 "downloader.c"
	} else {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3927 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD) (marshal_data ? marshal_data : cc->callback);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), data2);
#line 3933 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 3);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3952 "downloader.c"
	} else {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3958 "downloader.c"
	}
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (marshal_data ? marshal_data : cc->callback);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), g_value_get_pointer (param_values + 2), data2);
#line 3964 "downloader.c"
}


static void boxes_downloader_class_init (BoxesDownloaderClass * klass) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_parent_class = g_type_class_peek_parent (klass);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	g_type_class_add_private (klass, sizeof (BoxesDownloaderPrivate));
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_downloader_finalize;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_signals[BOXES_DOWNLOADER_DOWNLOADED_SIGNAL] = g_signal_new ("downloaded", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD, G_TYPE_NONE, 1, BOXES_TYPE_DOWNLOAD);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	boxes_downloader_signals[BOXES_DOWNLOADER_DOWNLOAD_FAILED_SIGNAL] = g_signal_new ("download_failed", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER, G_TYPE_NONE, 2, BOXES_TYPE_DOWNLOAD, G_TYPE_POINTER);
#line 3979 "downloader.c"
}


static void boxes_downloader_instance_init (BoxesDownloader * self) {
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self->priv = BOXES_DOWNLOADER_GET_PRIVATE (self);
#line 3986 "downloader.c"
}


static void boxes_downloader_finalize (GObject * obj) {
	BoxesDownloader * self;
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOADER, BoxesDownloader);
#line 19 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 21 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 17 "/home/fborges/checkout/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (boxes_downloader_parent_class)->finalize (obj);
#line 4000 "downloader.c"
}


GType boxes_downloader_get_type (void) {
	static volatile gsize boxes_downloader_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_downloader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_downloader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownloader), 0, (GInstanceInitFunc) boxes_downloader_instance_init, NULL };
		GType boxes_downloader_type_id;
		boxes_downloader_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDownloader", &g_define_type_info, 0);
		g_once_init_leave (&boxes_downloader_type_id__volatile, boxes_downloader_type_id);
	}
	return boxes_downloader_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 4019 "downloader.c"
		int i;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 4027 "downloader.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 4039 "downloader.c"
}



